@@ -290,9 +290,16 @@ def fill_seniority_column(df):
     return df
 
 
-def filter_countries(df, countries):
-    logger.info(f'Filtering the following countries: {countries}')
-    df = df[df['Country'].isin(countries)]
+def filter_countries(df, countries,fixed_filter):
+    if fixed_filter:
+        logger.info(f'countries out of top 10 go to other')
+        top = df['Country'].value_counts().head(10).index.tolist()
+        df.loc[~df['Country'].isin(top),'Country'] = 'other'
+
+    else:
+        logger.info(f'Filtering the following countries: {countries}')
+        df = df[df['Country'].isin(countries)]
+
     return df
 
 
